<p align="center">
    <img width="350" height="150" src="https://cdn.jsdelivr.net/gh/szj2ys/cdn/resources/langma/logo.png"/>
</p>

<h3 align="center">
    <p>Awesome NLP framework you are waiting for ✨</p>
</h3>


<p align="center">
    <a href="https://python.org/pypi/langma">
        <img src="https://badge.fury.io/py/langma.svg" alt="Version"/>
    </a>
    <a href="https://python.org/pypi/langma">
        <img src="https://img.shields.io/pypi/l/langma.svg?color=orange" alt="License"/>
    </a>
    <a href="https://python.org/pypi/langma">
        <img src="https://static.pepy.tech/badge/langma?color=blue" alt="pypi total downloads"/>
    </a>
    <a href="https://python.org/pypi/langma">
        <img src="https://img.shields.io/github/last-commit/szj2ys/langma?color=blue" alt="GitHub last commit"/>
    </a>
</p>

`langma` was the short name of `Qomolangma` , it's the highest mountain on Earth
Snow-capped mountains, azure sky, golden rays of sunshine, the pure and 
mysterious aura of Tibet has excited the imagination of so many people of the world. 

## Installation⚙ 🔑 🎛️ 🙈 🎠 ❌ 🎉 
```shell
pip install langma
```

Right now...`langma` is now on your environment, enjoy...

if you don't know what to do and how, enter `langma -h` for help on 
terminal

## REFERENCES
- [logly](https://www.logoly.pro/)
- [Kashgari](https://github.com/BrikerMan/Kashgari/)


<p align="center">
    <img src="https://cdn.jsdelivr.net/gh/szj2ys/cdn/resources/langma/everest.jpeg"/>
</p>

